@@ -2,7 +2,7 @@ context("ggdag_status")
 set.seed(1234)
 
 test_that("dags have correct status", {
-  dag <- dagify(
+  test_dag <- dagify(
     l ~ x + y,
     y ~ x,
     exposure = "x",
@@ -10,7 +10,7 @@ test_that("dags have correct status", {
     latent = "l"
   )
 
-  p <- ggdag_status(dag)
+  p <- ggdag_status(test_dag)
 
-  vdiffr::expect_doppelganger("ggdag_status() `x` as exposure, `y` as outcome, and `l` as latent", p)
+  expect_doppelganger("ggdag_status() `x` as exposure, `y` as outcome, and `l` as latent", p)
 })
